@@ -452,11 +452,11 @@ gtk_plot_bubble_get_legend_size(GtkPlotData *data, gint *width, gint *height)
     gtk_plot_axis_parse_label(data->gradient, bubble->scale_max, bubble->labels_precision, bubble->labels_style, text);
     if(bubble->labels_prefix){
       g_snprintf(aux_text, 100, "%s%s", bubble->labels_prefix, text);
-      g_snprintf(text, 100, aux_text);
+      memcpy(text, aux_text, 100*sizeof(gchar));
     }
     if(bubble->labels_suffix){
       g_snprintf(aux_text, 100, "%s%s", text, bubble->labels_suffix);
-      g_snprintf(text, 100, aux_text);
+      memcpy(text, aux_text, 100*sizeof(gchar));
     }
 
     g_snprintf(new_label, 100, "%s", text);
@@ -531,12 +531,12 @@ gtk_plot_bubble_draw_legend(GtkPlotData *data, gint x, gint y)
     if(bubble->labels_prefix){
       gchar aux_text[100];
       g_snprintf(aux_text, 100, "%s%s", bubble->labels_prefix, text_max);
-      g_snprintf(text_max, 100, aux_text);
+      memcpy(text_max, aux_text, 100*sizeof(gchar));
     }
     if(bubble->labels_suffix){
       gchar aux_text[100];
       g_snprintf(aux_text, 100, "%s%s", text_max, bubble->labels_suffix);
-      g_snprintf(text_max, 100, aux_text);
+      memcpy(text_max, aux_text, 100*sizeof(gchar));
     }
     g_snprintf(new_label, 100, "%s", text_max);
 
